@@ -4,15 +4,15 @@
 # replace level with .wmean(x|category) - .wmean(x)
 .catNum <- function(col,args,doCollar) {
   col <- .preProcCat(col,args$levRestriction)
-  novel <- !(col %in% names(args$scores))
+  unhandledNovel <- !(col %in% names(args$scores))
   keys <- col
   pred <- numeric(length(col))
   if(length(args$scores)>0) {
-    keys[novel] <- names(args$scores)[[1]]   # just to prevent bad lookups
+    keys[unhandledNovel] <- names(args$scores)[[1]]   # just to prevent bad lookups
     pred <- as.numeric(args$scores[keys]) 
   }
   # mean delta impact averaged over all possibilities, should be zero in scaled mode, mean dist in unscaled
-  pred[novel] <- 0.0 
+  pred[unhandledNovel] <- 0.0 
   pred
 }
 
@@ -20,7 +20,7 @@
 # see: http://www.win-vector.com/blog/2012/07/modeling-trick-impact-coding-of-categorical-variables-with-many-levels/
 .mkCatNum <- function(origVarName,vcolin,rescol,smFactor,levRestriction,weights) {
   vcol <- .preProcCat(vcolin,levRestriction)
-  extraModelDegrees <- max(0,length(unique(vcolin)))
+  extraModelDegrees <- max(0,length(unique(vcolin))-1)
   baseMean <- .wmean(rescol,weights)
   num <- tapply(rescol*weights,vcol,sum)
   den <- tapply(weights,vcol,sum)
