@@ -3,21 +3,21 @@
 # apply a prevalence fact
 .catP <- function(col,args,doCollar) {
   col <- .preProcCat(col,NULL)
-  novel <- !(col %in% names(args$scores))
+  unhandledNovel <- !(col %in% names(args$scores))
   keys <- col
   pred <- numeric(length(col))
   if(length(args$scores)>0) {
-    keys[novel] <- names(args$scores)[[1]]   # just to prevent bad lookups
+    keys[unhandledNovel] <- names(args$scores)[[1]]   # just to prevent bad lookups
     pred <- as.numeric(args$scores[keys]) 
   }
-  pred[novel] <- 0.0 
+  pred[unhandledNovel] <- 0.0 
   pred
 }
 
 # build a prevalence fact
 .mkCatP <- function(origVarName,vcolin,zoY,zC,zTarget,levRestriction,weights,catScaling) {
   vcol <- .preProcCat(vcolin,c())
-  extraModelDegrees <- max(0,length(unique(vcolin)))
+  extraModelDegrees <- max(0,length(unique(vcolin))-1)
   num <- tapply(weights,vcol,sum)
   den <- sum(weights)
   scores <- num/den
