@@ -76,9 +76,9 @@ print.vtreatment <- function(x,...) {
 #' @param weights optional training weights for each row
 #' @param minFraction optional minimum frequency a categorical level must have to be converted to an indicator column.
 #' @param smFactor optional smoothing factor for impact coding models.
-#' @param rareCount optional integer, suppress direct effects of level of this count or less.
-#' @param rareSig optional numeric, suppress direct effects of level of this significance value greater.  Set to one to turn off effect.
-#' @param collarProb what fraction of the data (pseudo-probability) to collar data at (<0.5).
+#' @param rareCount optional integer, allow levels with this count or below to be pooled into a shared rare-level.  Defaults to 0 or off.
+#' @param rareSig optional numeric, suppress levels from pooling at this significance value greater.  Defaults to NULL or off.
+#' @param collarProb what fraction of the data (pseudo-probability) to collar data at if doCollar is set during \code{\link{prepare}}.
 #' @param splitFunction (optional) see vtreat::buildEvalSets .
 #' @param ncross optional scalar >=2 number of cross validation splits use in rescoring complex variables.
 #' @param catScaling optional, if TRUE use glm() linkspace, if FALSE use lm() for scaling.
@@ -102,7 +102,7 @@ designTreatmentsC <- function(dframe,varlist,outcomename,outcometarget,
                               ...,
                               weights=c(),
                               minFraction=0.02,smFactor=0.0,
-                              rareCount=0,rareSig=1,
+                              rareCount=0,rareSig=NULL,
                               collarProb=0.00,
                               splitFunction=NULL,ncross=3,
                               catScaling=FALSE,
@@ -157,9 +157,9 @@ designTreatmentsC <- function(dframe,varlist,outcomename,outcometarget,
 #' @param weights optional training weights for each row
 #' @param minFraction optional minimum frequency a categorical level must have to be converted to an indicator column.
 #' @param smFactor optional smoothing factor for impact coding models.
-#' @param rareCount optional integer, suppress direct effects of level of this count or less.
-#' @param rareSig optional numeric, suppress direct effects of level of this significance value greater.  Set to one to turn off effect.
-#' @param collarProb what fraction of the data (pseudo-probability) to collar data at (<0.5).
+#' @param rareCount optional integer, allow levels with this count or below to be pooled into a shared rare-level.  Defaults to 0 or off.
+#' @param rareSig optional numeric, suppress levels from pooling at this significance value greater.  Defaults to NULL or off.
+#' @param collarProb what fraction of the data (pseudo-probability) to collar data at if doCollar is set during \code{\link{prepare}}.
 #' @param splitFunction (optional) see vtreat::buildEvalSets .
 #' @param ncross optional scalar >=2 number of cross validation splits use in rescoring complex variables.
 #' @param verbose if TRUE print progress.
@@ -181,7 +181,7 @@ designTreatmentsN <- function(dframe,varlist,outcomename,
                               ...,
                               weights=c(),
                               minFraction=0.02,smFactor=0.0,
-                              rareCount=0,rareSig=1,
+                              rareCount=0,rareSig=NULL,
                               collarProb=0.00,
                               splitFunction=NULL,ncross=3,
                               verbose=TRUE,
@@ -229,8 +229,9 @@ designTreatmentsN <- function(dframe,varlist,outcomename,
 #' @param varlist Names of columns to treat (effective variables).
 #' @param ... no additional arguments, declared to forced named binding of later arguments
 #' @param weights optional training weights for each row
-#' @param rareCount optional integer, suppress direct effects of level of this count or less.
-#' @param collarProb what fraction of the data (pseudo-probability) to collar data at (<0.5).
+#' @param minFraction optional minimum frequency a categorical level must have to be converted to an indicator column.
+#' @param rareCount optional integer, allow levels with this count or below to be pooled into a shared rare-level.  Defaults to 0 or off.
+#' @param collarProb what fraction of the data (pseudo-probability) to collar data at if doCollar is set during \code{\link{prepare}}.
 #' @param verbose if TRUE print progress.
 #' @param parallelCluster (optional) a cluster object created by package parallel or package snow
 #' @return treatment plan (for use with prepare)
@@ -249,6 +250,7 @@ designTreatmentsN <- function(dframe,varlist,outcomename,
 #' @export
 designTreatmentsZ <- function(dframe,varlist,
                               ...,
+                              minFraction=0.02,
                               weights=c(),
                               rareCount=0,
                               collarProb=0.00,
@@ -262,7 +264,7 @@ designTreatmentsZ <- function(dframe,varlist,
   treatments <- .designTreatmentsX(dframe,varlist,outcomename,ycol,
                      c(),c(),
                      weights,
-                     1.0,smFactor=0,
+                     minFraction,smFactor=0,
                      rareCount,rareSig=1,
                      collarProb,
                      NULL,3,
@@ -270,6 +272,7 @@ designTreatmentsZ <- function(dframe,varlist,
                      verbose,
                      parallelCluster)
   treatments$outcomeType <- 'None'
+  treatments$meanY <- NA
   treatments
 }
 
@@ -315,7 +318,7 @@ designTreatmentsZ <- function(dframe,varlist,
 #' @export
 prepare <- function(treatmentplan,dframe,pruneSig,
                     ...,
-                    scale=FALSE,doCollar=TRUE,
+                    scale=FALSE,doCollar=FALSE,
                     varRestriction=c(),
                     parallelCluster=NULL) {
   .checkArgs1(dframe=dframe,...)
@@ -390,9 +393,9 @@ prepare <- function(treatmentplan,dframe,pruneSig,
 #' @param weights optional training weights for each row
 #' @param minFraction optional minimum frequency a categorical level must have to be converted to an indicator column.
 #' @param smFactor optional smoothing factor for impact coding models.
-#' @param rareCount optional integer, suppress direct effects of level of this count or less.
-#' @param rareSig optional numeric, suppress direct effects of level of this significance value greater.  Set to one to turn off effect.
-#' @param collarProb what fraction of the data (pseudo-probability) to collar data at (<0.5).
+#' @param rareCount optional integer, allow levels with this count or below to be pooled into a shared rare-level.  Defaults to 0 or off.
+#' @param rareSig optional numeric, suppress levels from pooling at this significance value greater.  Defaults to NULL or off.
+#' @param collarProb what fraction of the data (pseudo-probability) to collar data at if doCollar is set during \code{\link{prepare}}.
 #' @param scale optional if TRUE replace numeric variables with regression ("move to outcome-scale").
 #' @param doCollar optional if TRUE collar numeric variables by cutting off after a tail-probability specified by collarProb during treatment design.
 #' @param splitFunction (optional) see vtreat::buildEvalSets .
@@ -428,7 +431,7 @@ mkCrossFrameCExperiment <- function(dframe,varlist,
                                     minFraction=0.02,smFactor=0.0,
                                     rareCount=0,rareSig=1,
                                     collarProb=0.00,
-                                    scale=FALSE,doCollar=TRUE,
+                                    scale=FALSE,doCollar=FALSE,
                                     splitFunction=NULL,ncross=3,
                                     catScaling=FALSE,
                                     parallelCluster=NULL) {
@@ -461,7 +464,8 @@ mkCrossFrameCExperiment <- function(dframe,varlist,
   zoY <- ifelse(zC==outcometarget,1,0)
   newVarsS <- treatments$scoreFrame$varName[(treatments$scoreFrame$varMoves) &
                                               (treatments$scoreFrame$sig<1)]
-  crossDat <- .mkCrossFrame(dframe,varlist,newVarsS,outcomename,zoY,
+  crossDat <- .mkCrossFrame(dframe,treatments,
+                            varlist,newVarsS,outcomename,zoY,
                             zC,outcometarget,
                             weights,
                             minFraction,smFactor,
@@ -505,9 +509,9 @@ mkCrossFrameCExperiment <- function(dframe,varlist,
 #' @param weights optional training weights for each row
 #' @param minFraction optional minimum frequency a categorical level must have to be converted to an indicator column.
 #' @param smFactor optional smoothing factor for impact coding models.
-#' @param rareCount optional integer, suppress direct effects of level of this count or less.
-#' @param rareSig optional numeric, suppress direct effects of level of this significance value greater.  Set to one to turn off effect.
-#' @param collarProb what fraction of the data (pseudo-probability) to collar data at (<0.5).
+#' @param rareCount optional integer, allow levels with this count or below to be pooled into a shared rare-level.  Defaults to 0 or off.
+#' @param rareSig optional numeric, suppress levels from pooling at this significance value greater.  Defaults to NULL or off.
+#' @param collarProb what fraction of the data (pseudo-probability) to collar data at if doCollar is set during \code{\link{prepare}}.
 #' @param scale optional if TRUE replace numeric variables with regression ("move to outcome-scale").
 #' @param doCollar optional if TRUE collar numeric variables by cutting off after a tail-probability specified by collarProb during treatment design.
 #' @param splitFunction (optional) see vtreat::buildEvalSets .
@@ -541,7 +545,7 @@ mkCrossFrameNExperiment <- function(dframe,varlist,outcomename,
                                     minFraction=0.02,smFactor=0.0,
                                     rareCount=0,rareSig=1,
                                     collarProb=0.00,
-                                    scale=FALSE,doCollar=TRUE,
+                                    scale=FALSE,doCollar=FALSE,
                                     splitFunction=NULL,ncross=3,
                                     parallelCluster=NULL) {
   .checkArgs(dframe=dframe,varlist=varlist,outcomename=outcomename,...)
@@ -573,7 +577,8 @@ mkCrossFrameNExperiment <- function(dframe,varlist,outcomename,
   zoY <- dframe[[outcomename]]
   newVarsS <- treatments$scoreFrame$varName[(treatments$scoreFrame$varMoves) &
                                               (treatments$scoreFrame$sig<1)]
-  crossDat <- .mkCrossFrame(dframe,varlist,newVarsS,outcomename,zoY,
+  crossDat <- .mkCrossFrame(dframe,treatments,
+                            varlist,newVarsS,outcomename,zoY,
                             zC,NULL,
                             weights,
                             minFraction,smFactor,
