@@ -34,9 +34,5 @@ test_that("testDataTable: DataTable works", {
       ev <- max(abs(dTrainCTreated[[v]]-dTrainCTreatedP[[v]]))
       expect_true(ev<1.0e-3)
     }
-    expect_true(max(abs(pmax(0,treatmentsC$PRESSRsquared)-pmax(0,treatmentsCP$PRESSRsquared)))<=1.0e-2)
-    expect_true(max(abs(pmax(0,treatmentsC$varScore)-pmax(0,treatmentsCP$varScore)))<=1.0e-2)
-    # this score depends strongly on pseudo random samples
-    expect_true(max(abs(pmax(0,treatmentsC$catPseudoRSquared)-pmax(0,treatmentsCP$catPseudoRSquared)))<=0.3)
   }
 })
\ No newline at end of file
